@@ -19,14 +19,13 @@ from typing import Any, NamedTuple, Sequence, Tuple, Union
 
 import numpy as np
 
-import hypothesis.internal.conjecture.utils as cu
-import hypothesis.strategies._internal.core as st
 from hypothesis import assume
 from hypothesis.errors import InvalidArgument
+from hypothesis.internal.conjecture import utils as cu
 from hypothesis.internal.coverage import check_function
 from hypothesis.internal.reflection import deprecated_posargs, proxies
 from hypothesis.internal.validation import check_type, check_valid_interval
-from hypothesis.strategies._internal import SearchStrategy, check_strategy
+from hypothesis.strategies._internal import SearchStrategy, check_strategy, core as st
 from hypothesis.strategies._internal.strategies import T
 from hypothesis.utils.conventions import UniqueIdentifier, not_set
 
@@ -41,7 +40,7 @@ BroadcastableShapes = NamedTuple(
 TIME_RESOLUTIONS = tuple("Y  M  D  h  m  s  ms  us  ns  ps  fs  as".split())
 
 
-@st.defines_strategy_with_reusable_values
+@st.defines_strategy(force_reusable_values=True)
 def from_dtype(dtype: np.dtype) -> st.SearchStrategy[Any]:
     """Creates a strategy which can generate any value of the given dtype."""
     check_type(np.dtype, dtype, "dtype")
@@ -279,7 +278,11 @@ class ArrayStrategy(SearchStrategy):
                 )
             result = out
 
-        return result.reshape(self.shape)
+        result = result.reshape(self.shape).copy()
+
+        assert result.base is None
+
+        return result
 
 
 @check_function
@@ -294,7 +297,7 @@ def fill_for(elements, unique, fill, name=""):
     return fill
 
 
-@st.defines_strategy
+@st.defines_strategy(force_reusable_values=True)
 @deprecated_posargs
 def arrays(
     dtype: Any,
@@ -413,7 +416,7 @@ def arrays(
     return ArrayStrategy(elements, shape, dtype, fill, unique)
 
 
-@st.defines_strategy
+@st.defines_strategy()
 @deprecated_posargs
 def array_shapes(
     *, min_dims: int = 1, max_dims: int = None, min_side: int = 1, max_side: int = None
@@ -445,7 +448,7 @@ def array_shapes(
     ).map(tuple)
 
 
-@st.defines_strategy
+@st.defines_strategy()
 def scalar_dtypes() -> st.SearchStrategy[np.dtype]:
     """Return a strategy that can return any non-flexible scalar dtype."""
     return st.one_of(
@@ -460,7 +463,7 @@ def scalar_dtypes() -> st.SearchStrategy[np.dtype]:
 
 
 def defines_dtype_strategy(strat: T) -> T:
-    @st.defines_strategy
+    @st.defines_strategy()
     @proxies(strat)
     def inner(*args, **kwargs):
         return strat(*args, **kwargs).map(np.dtype)
@@ -700,7 +703,7 @@ def array_dtypes(
     ).filter(_no_title_is_name_of_a_titled_field)
 
 
-@st.defines_strategy
+@st.defines_strategy()
 @deprecated_posargs
 def nested_dtypes(
     subtype_strategy: st.SearchStrategy[np.dtype] = scalar_dtypes(),
@@ -723,7 +726,7 @@ def nested_dtypes(
     ).filter(lambda d: max_itemsize is None or d.itemsize <= max_itemsize)
 
 
-@st.defines_strategy
+@st.defines_strategy()
 @deprecated_posargs
 def valid_tuple_axes(
     ndim: int, *, min_size: int = 0, max_size: int = None
@@ -772,7 +775,7 @@ def valid_tuple_axes(
     ).map(tuple)
 
 
-@st.defines_strategy
+@st.defines_strategy()
 @deprecated_posargs
 def broadcastable_shapes(
     shape: Shape,
@@ -1092,7 +1095,7 @@ def _hypothesis_parse_gufunc_signature(signature, all_checks=True):
     return _GUfuncSig(input_shapes=input_shapes, result_shape=result_shape)
 
 
-@st.defines_strategy
+@st.defines_strategy()
 def mutually_broadcastable_shapes(
     *,
     num_shapes: Union[UniqueIdentifier, int] = not_set,
@@ -1312,10 +1315,13 @@ class BasicIndexStrategy(SearchStrategy):
         else:
             while result[-1:] == [slice(None, None)] and data.draw(st.integers(0, 7)):
                 result.pop()
+        if len(result) == 1 and data.draw(st.booleans()):
+            # Sometimes generate bare element equivalent to a length-one tuple
+            return result[0]
         return tuple(result)
 
 
-@st.defines_strategy
+@st.defines_strategy()
 def basic_indices(
     shape: Shape,
     *,
@@ -1332,6 +1338,8 @@ def basic_indices(
     It generates tuples containing some mix of integers, :obj:`python:slice` objects,
     ``...`` (Ellipsis), and :obj:`numpy:numpy.newaxis`; which when used to index a
     ``shape``-shaped array will produce either a scalar or a shared-memory view.
+    When a length-one tuple would be generated, this strategy may instead return
+    the element which will index the first axis, e.g. ``5`` instead of ``(5,)``.
 
     * ``shape``: the array shape that will be indexed, as a tuple of integers >= 0.
       This must be at least two-dimensional for a tuple to be a valid basic index;
@@ -1378,7 +1386,7 @@ def basic_indices(
     )
 
 
-@st.defines_strategy
+@st.defines_strategy()
 @deprecated_posargs
 def integer_array_indices(
     shape: Shape,
